NoCache

Struct NoCache 

pub struct NoCache;
A no-op cache that doesn’t store anything

This is useful when caching needs to be disabled, for testing, or for environments where caching is not desired.

Example

use sigstore_cache::{NoCache, CacheAdapter, CacheKey};
use std::time::Duration;

let cache = NoCache;

// Set does nothing
cache.set(CacheKey::RekorPublicKey, b"data", Duration::from_secs(3600)).await?;

// Get always returns None
assert!(cache.get(CacheKey::RekorPublicKey).await?.is_none());